:mod:`densities` Module
=======================

There are three options for density sets, and the choice is made internally by
setting a variable in ``densities.py``. It is not intended for the user to use
this module.

.. automodule:: yeadon.densities
    :members:
    :undoc-members:
    :show-inheritance:

